..
   Copyright (C) 2011,2012 Jaakko Luttinen

   This file is licensed under Version 3.0 of the GNU General Public
   License. See LICENSE for a text of the license.

   This file is part of BayesPy.

   BayesPy is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License version 3 as
   published by the Free Software Foundation.

   BayesPy is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with BayesPy.  If not, see <http://www.gnu.org/licenses/>.

BayesPy -- Bayesian Python
==========================


.. toctree::
   :maxdepth: 2
   
   intro
   user_guide/user_guide
   examples/examples
   dev_guide/dev_guide
   user_api/user_api
   dev_api/dev_api
   references

* :doc:`Bibliography <references>`
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

